@@ -281,6 +281,8 @@ class PostProcessor:
         self.run_prepost()
 
         for process, datasets in tqdm(self.targets["processes"]):
+            if process == "births":
+                print("stop")
             if process in self.parameters["parameters"].get(
                 "processes", {}
             ):  # If we assigned parameters
